// FILE:   Lab4_cpu02.c

#include "F28x_Project.h"

// Function Prototypes
interrupt void ipc2_isr(void);

// Variables
#define RESULTS_BUFFER_SIZE 256
Uint16 AdcaResults[RESULTS_BUFFER_SIZE];
Uint16 resultsIndex;
extern int QuadratureTable[40];
Uint16 sineData = 0;


void main(void)
{
// Initialize System Control
   InitSysCtrl();

// Clear all interrupts and initialize PIE control registers
	DINT;
	InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags
	IER = 0x0000;
	IFR = 0x0000;

// Initialize the PIE vector table
	InitPieVectTable();

// Map ISR functions
	EALLOW;
	PieVectTable.IPC1_INT = &ipc2_isr;		// IPC2 interrupt
	EDIS;

// Initialize results buffer
    for(resultsIndex = 0; resultsIndex < RESULTS_BUFFER_SIZE; resultsIndex++)
    {
    	AdcaResults[resultsIndex] = 0;
    }
    resultsIndex = 0;

    IpcRegs.IPCCLR.bit.IPC2 = 1;
    PieCtrlRegs.PIEACK.all = PIEACK_GROUP1;

//enable PIE interrupts
    PieCtrlRegs.PIEIER1.bit.INTx14 = 1;		// Enable IPC2 ISR
    PieCtrlRegs.PIEIFR1.bit.INTx13 = 1;		// Force first IPC1 transfer

// Enable global interrupts and higher priority real-time debug events:
	IER |= M_INT1; 						// Enable group 1 interrupts
	EINT;       						// Enable Global interrupt INTM
	ERTM;   							// Enable Global real-time interrupt DBGM

// Let CPU1 know that CPU2 is ready
	IpcRegs.IPCSET.bit.IPC17 = 1;		// Set IPC17 to release CPU1

	while(1)
	{
		;
	}
}


interrupt void ipc2_isr(void)
{
	// Read back ADC-A0 results and store in circular buffer
	AdcaResults[resultsIndex++] = (Uint16) IpcRegs.IPCRECVDATA;
	if(RESULTS_BUFFER_SIZE <= resultsIndex)
	{
		resultsIndex = 0;
	}

	// Write next data point from sine table
	sineData = (QuadratureTable[resultsIndex % 0x20] ^ 0x8000) >> 5;
	IpcRegs.IPCSENDADDR = (Uint16) sineData;
	IpcRegs.IPCSET.bit.IPC0 = 1;				// Set IPC1 bit for CPU1

	// Return from interrupt
	IpcRegs.IPCACK.bit.IPC1 = 1;				// Clear IPC2 bit
	PieCtrlRegs.PIEACK.all = PIEACK_GROUP1;		// Acknowledge PIE group 1 to enable further interrupts
}

// end of file
